@@ -688,7 +688,7 @@ class Cvt_Int_SwPortTrkAlw(CvtContext_Int):
 
         # we're removing all commands allowing VLANs which is a special
         # case as this actually means 'allow all'
-        return *self.enter(int_name), " no switchport trunk allowed vlan"
+        return [*self.enter(int_name), " no switchport trunk allowed vlan"]
 
     def truncate(self, old, rem, int_name):
         # if this interface is in a port-channel, we do all changes
